#__main__.py
from sample import sample
import json

def main():
    print("This is main")
if __name__ == "main":
    main()

